pub enum AssumptionSource {
UserSupplied,
Checked,
Unverified,
}Expand description
Where an assumption came from.
Variants
UserSupplied
Supplied by the caller and not verified by the engine.
Checked
Checked by the engine for the supplied data.
Unverified
Required by the method but not verifiable from the supplied inputs.