pub enum ExampleExpectation {
Value(Value),
Error(ErrorCode),
Contains(String),
}Expand description
Expected outcome of a documented example.
Serialized explicitly because an internally tagged enum cannot represent newtype variants whose payload is not a map (booleans, arrays, strings).
Variants