pub struct ParamDescriptor {
pub name: String,
pub description: String,
pub schema: ValueSchema,
pub required: bool,
pub numeric_shorthand: bool,
pub positional: bool,
}Expand description
A function parameter.
Fields
name: Stringdescription: Stringschema: ValueSchemarequired: boolnumeric_shorthand: boolWhether a string may be used as a numeric shorthand for this parameter.
positional: boolWhether the parameter may be supplied positionally in expressions.
Implementations
Sourceimpl ParamDescriptor
impl ParamDescriptor
pub fn required( name: impl Into<String>, description: impl Into<String>, schema: ValueSchema, ) -> ParamDescriptor
pub fn optional( name: impl Into<String>, description: impl Into<String>, schema: ValueSchema, ) -> ParamDescriptor
pub fn with_shorthand(self, allowed: bool) -> Self
pub fn with_positional(self, allowed: bool) -> Self