Typed parameter and output schemas with shared validation semantics.
Structs
- Field
Schema - A named field in a record schema.
Enums
- Number
Kind - Accepted numeric kinds for a parameter.
- Value
Schema - The schema of a single value.
Functions
- bound
- Convenience: an unbounded finite bound value.
- bound_
endpoint - Extract a finite bound as a concrete endpoint, or
Nonewhen unbounded. - exact_
number_ array - Convenience: an exact-number array schema.
- expect_
dimension - Extract a required dimension from a value, for unit-aware functions.
- finite_
scalar - Convenience: a finite scalar schema.
- float64_
array - Convenience: a finite float64 array schema.
- integer
- Convenience: a positive integer schema (validated by the function).